2024-06-17 Version: 3.1.0
- Support API ListTagResources.
- Support API MoveResourceGroup.
- Support API TagResources.
- Support API UntagResources.


2024-05-16 Version: 3.0.2
- Update API CreateExpressConnectRouter: add param Tags.
- Update API CreateExpressConnectRouterAssociation: update param AllowedPrefixes.
- Update API ModifyExpressConnectRouterAssociationAllowedPrefix: update param AllowedPrefixes.


2024-03-26 Version: 3.0.1
- Update API DescribeExpressConnectRouterChildInstance: update response param.


2024-03-22 Version: 3.0.0
- Update API DescribeExpressConnectRouterAllowedPrefixHistory: add param AssociationId.
- Update API DescribeExpressConnectRouterAllowedPrefixHistory: delete param AssociatonId.


2024-03-19 Version: 2.0.0
- Delete API GetExpressConnectRouter.


2024-03-12 Version: 1.0.0
- Generated python 2023-09-01 for ExpressConnectRouter.

